==> openflowplugin-extension-nicira-0.10.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/AllMatchesGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * grouping all-matches-grouping {
 *   uses nxm-nx-reg-grouping;
 *   uses nxm-nx-tun-id-grouping;
 *   uses nxm-nx-arp-sha-grouping;
 *   uses nxm-nx-arp-tha-grouping;
 *   uses nxm-of-arp-op-grouping;
 *   uses nxm-of-arp-spa-grouping;
 *   uses nxm-of-arp-tpa-grouping;
 *   uses nxm-of-in-port-grouping;
 *   uses nxm-nx-tun-ipv4-dst-grouping;
 *   uses nxm-nx-tun-ipv4-src-grouping;
 *   uses nxm-of-eth-src-grouping;
 *   uses nxm-of-eth-dst-grouping;
 *   uses nxm-of-eth-type-grouping;
 *   uses nxm-nx-nsp-grouping;
 *   uses nxm-nx-nsi-grouping;
 *   uses nxm-nx-nshc-1-grouping;
 *   uses nxm-nx-nshc-2-grouping;
 *   uses nxm-nx-nshc-3-grouping;
 *   uses nxm-nx-nshc-4-grouping;
 *   uses nxm-nx-nsh-flags-grouping;
 *   uses nxm-nx-nsh-mdtype-grouping;
 *   uses nxm-nx-nsh-np-grouping;
 *   uses nxm-nx-nsh-ttl-grouping;
 *   uses nxm-of-tcp-src-grouping;
 *   uses nxm-of-tcp-dst-grouping;
 *   uses nxm-of-udp-src-grouping;
 *   uses nxm-of-udp-dst-grouping;
 *   uses nxm-nx-ct-state-grouping;
 *   uses nxm-nx-ct-zone-grouping;
 *   uses nxm-of-ip-dst-grouping;
 *   uses nxm-of-ip-src-grouping;
 *   uses nxm-of-icmp-type-grouping;
 *   uses nxm-nx-ct-mark-grouping;
 *   uses nxm-nx-ct-tp-src-grouping;
 *   uses nxm-nx-ct-tp-dst-grouping;
 *   uses nxm-nx-pkt-mark-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/all-matches-grouping</i>
 *
 */
public interface AllMatchesGrouping
    extends
    DataObject,
    NxmNxCtZoneGrouping,
    NxmOfTcpSrcGrouping,
    NxmNxNshNpGrouping,
    NxmOfEthDstGrouping,
    NxmNxCtTpSrcGrouping,
    NxmNxNshc4Grouping,
    NxmNxTunIdGrouping,
    NxmNxCtTpDstGrouping,
    NxmOfUdpDstGrouping,
    NxmNxRegGrouping,
    NxmOfInPortGrouping,
    NxmNxCtMarkGrouping,
    NxmOfEthTypeGrouping,
    NxmNxNspGrouping,
    NxmNxNshTtlGrouping,
    NxmNxNshc2Grouping,
    NxmOfIpDstGrouping,
    NxmNxCtStateGrouping,
    NxmNxTunIpv4SrcGrouping,
    NxmOfUdpSrcGrouping,
    NxmNxArpThaGrouping,
    NxmNxTunIpv4DstGrouping,
    NxmNxNsiGrouping,
    NxmOfEthSrcGrouping,
    NxmOfTcpDstGrouping,
    NxmNxNshc3Grouping,
    NxmOfIpSrcGrouping,
    NxmOfArpSpaGrouping,
    NxmNxPktMarkGrouping,
    NxmNxArpShaGrouping,
    NxmNxNshc1Grouping,
    NxmNxNshFlagsGrouping,
    NxmOfIcmpTypeGrouping,
    NxmOfArpOpGrouping,
    NxmOfArpTpaGrouping,
    NxmNxNshMdtypeGrouping
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("all-matches-grouping");

    @Override
    Class<? extends AllMatchesGrouping> implementedInterface();

}

==> openflowplugin-extension-nicira-0.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/AllMatchesGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * grouping all-matches-grouping {
 *   uses nxm-nx-reg-grouping;
 *   uses nxm-nx-tun-id-grouping;
 *   uses nxm-nx-arp-sha-grouping;
 *   uses nxm-nx-arp-tha-grouping;
 *   uses nxm-of-arp-op-grouping;
 *   uses nxm-of-arp-spa-grouping;
 *   uses nxm-of-arp-tpa-grouping;
 *   uses nxm-of-in-port-grouping;
 *   uses nxm-nx-tun-ipv4-dst-grouping;
 *   uses nxm-nx-tun-ipv4-src-grouping;
 *   uses nxm-of-eth-src-grouping;
 *   uses nxm-of-eth-dst-grouping;
 *   uses nxm-of-eth-type-grouping;
 *   uses nxm-nx-nsp-grouping;
 *   uses nxm-nx-nsi-grouping;
 *   uses nxm-nx-nshc-1-grouping;
 *   uses nxm-nx-nshc-2-grouping;
 *   uses nxm-nx-nshc-3-grouping;
 *   uses nxm-nx-nshc-4-grouping;
 *   uses nxm-nx-nsh-flags-grouping;
 *   uses nxm-nx-nsh-mdtype-grouping;
 *   uses nxm-nx-nsh-np-grouping;
 *   uses nxm-nx-nsh-ttl-grouping;
 *   uses nxm-of-tcp-src-grouping;
 *   uses nxm-of-tcp-dst-grouping;
 *   uses nxm-of-udp-src-grouping;
 *   uses nxm-of-udp-dst-grouping;
 *   uses nxm-nx-ct-state-grouping;
 *   uses nxm-nx-ct-zone-grouping;
 *   uses nxm-of-ip-dst-grouping;
 *   uses nxm-of-ip-src-grouping;
 *   uses nxm-of-icmp-type-grouping;
 *   uses nxm-nx-ct-mark-grouping;
 *   uses nxm-nx-ct-tp-src-grouping;
 *   uses nxm-nx-ct-tp-dst-grouping;
 *   uses nxm-nx-pkt-mark-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/all-matches-grouping</i>
 *
 */
public interface AllMatchesGrouping
    extends
    DataObject,
    NxmNxRegGrouping,
    NxmNxTunIdGrouping,
    NxmNxArpShaGrouping,
    NxmNxArpThaGrouping,
    NxmOfArpOpGrouping,
    NxmOfArpSpaGrouping,
    NxmOfArpTpaGrouping,
    NxmOfInPortGrouping,
    NxmNxTunIpv4DstGrouping,
    NxmNxTunIpv4SrcGrouping,
    NxmOfEthSrcGrouping,
    NxmOfEthDstGrouping,
    NxmOfEthTypeGrouping,
    NxmNxNspGrouping,
    NxmNxNsiGrouping,
    NxmNxNshc1Grouping,
    NxmNxNshc2Grouping,
    NxmNxNshc3Grouping,
    NxmNxNshc4Grouping,
    NxmNxNshFlagsGrouping,
    NxmNxNshMdtypeGrouping,
    NxmNxNshNpGrouping,
    NxmNxNshTtlGrouping,
    NxmOfTcpSrcGrouping,
    NxmOfTcpDstGrouping,
    NxmOfUdpSrcGrouping,
    NxmOfUdpDstGrouping,
    NxmNxCtStateGrouping,
    NxmNxCtZoneGrouping,
    NxmOfIpDstGrouping,
    NxmOfIpSrcGrouping,
    NxmOfIcmpTypeGrouping,
    NxmNxCtMarkGrouping,
    NxmNxCtTpSrcGrouping,
    NxmNxCtTpDstGrouping,
    NxmNxPktMarkGrouping
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("all-matches-grouping");

    @Override
    Class<? extends AllMatchesGrouping> implementedInterface();

}
